@@ -1,21 +1,9 @@
 import copy
-import operator
-import typing
 from dataclasses import dataclass
-from pprint import pprint
-from typing import (
-    Any,
-    ClassVar,
-    Generic,
-    Literal,
-    Optional,
-    Protocol,
-    Type,
-    TypedDict,
-    TypeVar,
-)
+from typing import ClassVar, Generic, Optional, Protocol, Type, TypeVar
 
 from fastapi import HTTPException
+from fastapi_resources.resources import base_resource, types
 from sqlalchemy.engine import Engine
 from sqlalchemy.orm import MANYTOONE, ONETOMANY
 from sqlalchemy.orm import exc as sa_exceptions
@@ -23,8 +11,6 @@ from sqlalchemy.orm import joinedload
 from sqlmodel import Session, SQLModel, select, update
 from sqlmodel.sql.expression import SelectOfScalar
 
-from fastapi_resources.resources import base_resource, types
-
 
 @dataclass
 class SchemaWithRelationships:
@@ -92,22 +78,6 @@ class SQLResourceProtocol(types.ResourceProtocol, Protocol, Generic[TDb]):
         ...
 
 
-def get_related_schema(annotation: Any):
-    args = typing.get_args(annotation)
-    if args:
-        generic_arg = args[0]
-        if issubclass(generic_arg, SQLModel):
-            # Generic assumes first arg is the model
-            return generic_arg
-
-        raise ValueError("Unsupported generic relationship type. Must be a single arg.")
-
-    if issubclass(annotation, SQLModel):
-        return annotation
-
-    raise ValueError(f"Unsupported relationship type {annotation}")
-
-
 def get_relationships_from_schema(
     schema: Type[SQLModel],
     schema_cache: Optional[
@@ -121,7 +91,6 @@ def get_relationships_from_schema(
 ):
     schema_cache = schema_cache or {}
 
-    annotations = typing.get_type_hints(schema)
     relationship_fields = schema.__sqlmodel_relationships__.keys()
     relationships = {}
 
@@ -137,15 +106,13 @@ def get_relationships_from_schema(
     schema_cache[(parent_key, schema)] = parent_schema_with_relationships
 
     for field in relationship_fields:
-        annotated_type = annotations[field]
-        related_schema = get_related_schema(annotated_type)
-        many = typing.get_origin(annotated_type) == list
+        sqlalchemy_relationship = getattr(schema, field).property
+        related_schema = sqlalchemy_relationship.mapper.class_
+        many = sqlalchemy_relationship.uselist
 
         # Used to uniquely identify the related schema relative to a parent
         new_parent_key = f"{schema}.{field}"
 
-        sqlalchemy_relationship = getattr(schema, field).property
-
         # TODO: Handle MANYTOMANY
         direction = sqlalchemy_relationship.direction
         update_field = list(
